<template>
  <LoadingLayout :loading="state.loading">
    <AppScrollContainer>
      <ChunkCell title="1">
        <template #title>
          <el-text>{{ `保单号：${'958585860689'}` }}</el-text>
          <el-text>{{ `投保人：${'人力无忧'}` }}</el-text>
        </template>
        <ProForm :model="state.form" ref="formRef" label-width="120px">
          <ProFormCol>
            <ProFormColItem :span="8">
              <ProFormItemV2
                label="期望生效日期:"
                prop="time"
                :check-rules="[{ message: '请选择日期' }]"
              >
                <ProFormDatePicker
                  v-model="state.form.time"
                  type="date"
                  value-format="YYYY-MM-DD"
                  placeholder="请选择日期"
                ></ProFormDatePicker>
              </ProFormItemV2>
            </ProFormColItem>
          </ProFormCol>
          <ProFormCol>
            <ProFormColItem :span="8">
              <ProFormItemV2 label="" prop="url" label-width="0">
                <ProFormUpload
                  v-model:file-url="state.form.url"
                  :limit="1"
                  :limitFileSize="10"
                  accept="xlsx,xls"
                  :showTip="false"
                >
                  <template #default>
                    <el-button type="primary">加减人</el-button>
                    <el-button link type="primary" @click.stop="handleTemplateDownload"
                      >下载模板</el-button
                    >
                  </template>
                </ProFormUpload>
              </ProFormItemV2>
            </ProFormColItem>
          </ProFormCol>
          <ProFormCol>
            <ProFormColItem :span="8">
              <ProFormItemV2 label="" prop="url" label-width="0">
                <ProFormUpload
                  v-model:file-url="state.form.url"
                  :limit="1"
                  :limitFileSize="10"
                  accept="xlsx,xls"
                  :showTip="false"
                >
                  <template #default>
                    <el-button type="primary">替换人</el-button>
                    <el-button link type="primary" @click.stop="handleTemplateDownload"
                      >下载模板</el-button
                    >
                  </template>
                </ProFormUpload>
              </ProFormItemV2>
            </ProFormColItem>
          </ProFormCol>
        </ProForm>
      </ChunkCell>
      <ChunkCell title="批改人员详情">
        <template #titleRight>
          <el-button type="primary" @click="handleClear">清空数据</el-button>
        </template>
        <ProTableV2
          v-bind="proTableProps"
          :columns="column"
          :show-operation-column="false"
          :auto-height="false"
          ref="proTable"
          :tableProps="{
            maxHeight: '400px',
          }"
        >
        </ProTableV2>
        <div class="chuck-add-or-edit-actions">
          <el-button class="chuck-add-or-edit-actions" type="primary" @click="handleSubmit"
            >提交</el-button
          >
        </div>
      </ChunkCell>
    </AppScrollContainer>
  </LoadingLayout>
</template>

<script setup lang="ts">
import {
  LoadingLayout,
  AppScrollContainer,
  ProForm,
  ProFormItemV2,
  ChunkCell,
  ProFormText,
  ProTableQueryFilterBar,
  QueryFilterItem,
  SearchInput,
  ProFormCol,
  ProFormColItem,
  ProFormDatePicker,
  ProFormInputNumber,
  useTable,
  ProTableV2,
  ProFormRadio,
  FieldSelect,
  defineOperationBtns,
  useFormDialog,
  ProFormUpload,
  UploadUserFile,
} from '@bole-core/components';
import * as insuranceOrderServices from '@/services/api/InsuranceOrder';
import { OrderInputType } from '@bole-core/core';

defineOptions({
  name: 'BatchChange',
});

const column: API.CustomModuleColumnDto[] = [
  {
    id: '1',
    enCode: 'name',
    name: '批改类型',
  },
  {
    id: '2',
    enCode: 'name',
    name: '姓名',
  },
  {
    id: '3',
    enCode: 'name',
    name: '身份证号',
  },
  {
    id: '4',
    enCode: 'idNumber',
    name: '雇员工种',
  },
  {
    id: '5',
    enCode: 'idNumber',
    name: '性别',
  },
  {
    id: '6',
    enCode: 'idNumber',
    name: '年龄',
  },
  {
    id: '7',
    enCode: 'idNumber',
    name: '出生日期',
  },
  {
    id: '8',
    enCode: 'idNumber',
    name: '手机号码',
  },
];

const route = useRoute();
const id = route.params.id as string;
const BaseState = {
  loading: true,
  form: {
    time: '',
    url: [] as UploadUserFile[],
  },
};

const state = reactive({ ...BaseState });

const {
  getDataSource: getBatchRefundInfoDetail,
  proTableProps,
  paginationState,
  extraParamState,
  reset,
} = useTable(
  async ({ pageIndex, pageSize }, extraParamState) => {
    try {
      let params: API.QueryInsuranceOrderPageInput = {
        pageModel: {
          rows: pageSize,
          page: pageIndex,
          orderInput: extraParamState.orderInput,
        },
        condition: extraParamState.keyWord,
        // insurePolicyOperateHistoryId: id,
      };
      let res = await insuranceOrderServices.getInsuranceOrderPage(params, {
        showLoading: !state.loading,
      });
      return res;
    } catch (error) {}
  },
  {
    defaultExtraParams: {
      keyWord: '',
      orderInput: [{ property: 'id', order: OrderInputType.Asc }],
    },
    columnsRenderProps: {},
  }
);

function handleClear() {}
function handleSubmit() {}
function handleTemplateDownload() {}

onMounted(async () => {
  await getBatchRefundInfoDetail();
  state.loading = false;
});
</script>

<style lang="scss" scoped>
@use '@/style/common.scss' as *;

.chuck-add-or-edit-actions {
  //   margin-bottom: 20px;
}
</style>
